// pages/components/PlatformFeeChart/PlatformFeeChart.js
let platforFeeChart = null;
let month = '';

function initChart(canvas, width, height, F2) {
  const data = [];
  platforFeeChart = new F2.Chart({
    el: canvas,
    width,
    height,
  });

  platforFeeChart.source(data, {
    month: {
      min: 1,
      max: 12,
    },
  });
  platforFeeChart.tooltip({
    showItemMarker: false,
    background: {
      radius: 2,
      fill: '#6895fe',
      padding: [6, 10],
    },
    onShow(ev) {
      const { items } = ev;
      items[0].name = '';
      items[0].value = items[0].title + '月';
      items[1].name = '';
      items[1].value = items[1].value + '元';
    },
  });
  platforFeeChart
    .line()
    .position('month*totalMoney')
    .color('#6895fe')
    .shape('smooth')
    .size(4);
  platforFeeChart
    .area()
    .position('month*totalMoney')
    .color('l(90) 0:#6895fe 1:#fff')
    .shape('smooth')
    .style({
      fillOpacity: 0.6,
    });
  // platforFeeChart.axis('rechargeMoney', false);
  platforFeeChart.render();
  return platforFeeChart;
}

function findMaxIndex(list, key) {
  if (!list.length) return -1;
  let max = list[0][key];
  let maxIndex = 0;
  for (let index = 0; index < list.length; index++) {
    const element = list[index];
    if (element >= max) maxIndex = index;
  }
  return maxIndex;
}

Component({
  lifetimes: {
    attached() {
      const query = wx.createSelectorQuery().in(this);
      query
        .select('#PlatformFeeChart')
        .boundingClientRect(res => {
          // res.top; // 这个组件内 #the-id 节点的上边界坐标
          console.log(res);
          this.setData({
            x: res.left,
            y: res.top,
          });
        })
        .exec();
    },
  },

  properties: {
    dataList: {
      type: Array,
      value: [],
      observer(newVal) {
        platforFeeChart && platforFeeChart.changeData(newVal);
        if (platforFeeChart) {
          let index = findMaxIndex(newVal, 'totalMoney');
          if (index !== -1) {
            let item = newVal[index];
            const point = platforFeeChart.getPosition(item);
            platforFeeChart.showTooltip(point);
          }
        }
      },
    },
    month: {
      type: String,
      value: '',
      observer(newVal) {
        month = newVal;
      },
    },
  },
  data: {
    opts: {
      onInit: initChart,
    },
    x: 0,
    y: 0,
  },
  methods: {
    clickHandle(e) {
      console.log(e.detail);
      let x = e.detail.x - this.data.x;
      let y = e.detail.y - this.data.y;
      const objArr = platforFeeChart.getSnapRecords({ x, y });
      if (objArr.length) this.triggerEvent('selectedData', objArr[0]._origin);
    },
  },
});
